@@ -3,7 +3,7 @@ use Modern::Perl qw(2012);
 use Kavorka;
 use Types::Standard qw(ArrayRef Str);
 use Text::CSV::Slurp;
-use File::Slurp::Tiny 'write_file';
+use File::Slurp::Tiny qw(write_file read_file);
 use Exporter::Tidy all => [qw(exec_commands write_data)];
 use File::Temp qw(tempfile);
 use Carp::Assert;
@@ -57,6 +57,8 @@ The function takes a string of gnuplot commands $c that is piped to gnuplot. You
 Then, any occurences of __DATA__ in $c are replaced by a temp file containing $data transformed to gnuplot format as
 done by write_data.
 
+The function throws the gnuplot error message if execution fails. 
+
 =head1 LICENSE
 
 This software is licensed under the same terms as Perl itself.
@@ -86,8 +88,13 @@ fun _transform ( ArrayRef $data) {
     join( "\n", map { $csv->combine(@$_); $csv->string(); } @$data );
 }
 
+#@data refers to the possibility of multiple data sets, which has not been implemented yet.
 fun exec_commands ( Str $c, @data ) {
-    open my $proc, "|gnuplot";
+
+    my ( $eh, $errfile ) = tempfile();
+
+    open my $proc, "|gnuplot 2>$errfile" or die "Could not open pipe to gnuplot.";
+
     my $tmp = File::Temp->new();
     my $tfn = $tmp->filename();
     write_data( $tfn, @data );
@@ -95,10 +102,13 @@ fun exec_commands ( Str $c, @data ) {
     #use placeholder to replace all occurences
     $c =~ s/__DATA__/'$tfn'/g;
 
-    print $proc $c;
-
     binmode $proc, ":utf8";
+    ( print $proc $c ) or die "Failed to input commands to gnuplot.";
+
     close $proc;
+
+    my $err = read_file( $errfile, binmode => ":utf8" );
+    $err && die "Gnuplot execution failed:\n$err";
 }
 
 1;
